shithub: cstory

Download patch

ref: 6ea58290f49945ef34d374bb0fc8f6c97aa7a4e7
parent: b3e40b047577ea6d11564daa27652470d6279e3c
author: Clownacy <[email protected]>
date: Sat Apr 4 16:57:34 EDT 2020

Set SDL2 audio backend to 48000Hz

--- a/src/Backends/Audio/SDL2.cpp
+++ b/src/Backends/Audio/SDL2.cpp
@@ -76,10 +76,10 @@
 		puts(SDL_GetAudioDriver(i));
 
 	SDL_AudioSpec specification;
-	specification.freq = 44100;
+	specification.freq = 48000;
 	specification.format = AUDIO_F32;
 	specification.channels = 2;
-	specification.samples = 0x400;	// Roughly 10 milliseconds for 44100Hz
+	specification.samples = 0x400;	// Roughly 10 milliseconds for 48000Hz
 	specification.callback = Callback;
 	specification.userdata = NULL;